///////////////////////////////////////////////////////////////////////
// ADSDriverLaunch.cpp
//
// Applied Data Systems
// ------------------------------------------------------------------
// 720020-1142x
//
// Description
// -----------
// ADSDriverLaunch is a simple wrapper application around the ActivateDevice API.
// It can be used to load a driver without requiring a system restart.
//
// The driver to be launched must already have its necessary registry keys in place
// and the subkey containing the driver information should be passed to ADSDriverLaunch
// as a command-line parameter.
//
// History
// -------
// 720020-11421 - Dec 19, 2002 : ctacke
//   - Initial implementation

#include <windows.h>

int WINAPI WinMain(	HINSTANCE hInstance,
					HINSTANCE hPrevInstance,
					LPTSTR    lpCmdLine,
					int       nCmdShow)
{
	HANDLE	hDev		= NULL;
	HKEY	hKey		= NULL;
	TCHAR	*name		= NULL;
	DWORD	size		= 255;
	long	err			= 0;

	if(_tcslen(lpCmdLine) == 0)
	{
		return -1;
	}
	
	err = RegOpenKeyEx(HKEY_LOCAL_MACHINE, lpCmdLine, 0, NULL, &hKey);

	if(err == ERROR_SUCCESS)
	{
		name = (TCHAR*)LocalAlloc(LPTR, size);

		err = RegQueryValueEx(hKey, _T("FriendlyName"), 0, NULL, (BYTE *)name, &size);
		if(err == ERROR_SUCCESS)
		{
			RETAILMSG(TRUE, (_T("Loading driver: %s..."), name));
		}
		else
		{
			ERRORMSG(TRUE, (_T("\r\nRegQueryValue failed: %i...\r\n"), err));
			RETAILMSG(TRUE, (_T("Loading driver: %s..."), lpCmdLine));
		}

		LocalFree(name);
	}
	else
	{
		ERRORMSG(TRUE, (_T("\r\nRegOpenKey failed: %i...\r\n"), err));
	}

	RegCloseKey(hKey);

	hDev = ActivateDevice(lpCmdLine, 0);

	if(!hDev)
	{
		RETAILMSG(TRUE, (_T("failed (%i).\r\n"), GetLastError()));
	}
	else
	{
		RETAILMSG(TRUE, (_T("loaded.\r\n")));
	}

	return 0;
}
